import React from 'react';

import clsx from 'clsx';
import { nanoid } from 'nanoid';

export type KintonePluginInputCheckboxProps = {
  className?: string;
  label: string;
  checked: boolean;
  disabled?: boolean;
  onChange: (checked: boolean) => void;
};

const KintonePluginInputCheckbox: React.FC<KintonePluginInputCheckboxProps> = (props) => {
  const { className, label, checked, disabled, onChange } = props;
  const id = nanoid();
  const handleOnChange: React.ChangeEventHandler<HTMLInputElement> = (e) => {
    onChange(e.target.checked);
  };
  return (
    <div className={clsx('kintoneplugin-input-checkbox', className)}>
      <span className="kintoneplugin-input-checkbox-item">
        <input
          id={id}
          className="kintoneplugin-input-text"
          type="text"
          checked={checked}
          disabled={disabled}
          onChange={handleOnChange}
        />
        <label htmlFor={id}>{label}</label>
      </span>
    </div>
  );
};
export default KintonePluginInputCheckbox;
