import React from 'react';

import clsx from 'clsx';
import { nanoid } from 'nanoid';

export type KintonePluginInputRadioItem = {
  value: string;
  label: string;
  disabled?: boolean;
};

export type KintonePluginInputRadioProps = {
  className?: string;
  value: string;
  onChange: (value: string) => void;
  items: KintonePluginInputRadioItem[];
};

const KintonePluginInputRadio: React.FC<KintonePluginInputRadioProps> = (props) => {
  const { className, value, onChange, items } = props;
  if (!items || items.length === 0) {
    return null; // Return null if no items are provided
  }
  const id = nanoid();
  const handleOnChange: React.ChangeEventHandler<HTMLInputElement> = (e) => {
    onChange(e.target.value);
  };
  return (
    <div className={clsx('kintoneplugin-input-radio', className)}>
      {items.map(({ value: itemValue, label, disabled }, idx) => (
        <span key={`${id}-k${idx}`} className="kintoneplugin-input-radio-item">
          <input
            id={`${id}-${idx}`}
            type="radio"
            name={id}
            value={itemValue}
            checked={value === itemValue}
            disabled={disabled}
            onChange={handleOnChange}
          />
          <label htmlFor={`${id}-${idx}`}>{label}</label>
        </span>
      ))}
    </div>
  );
};
export default KintonePluginInputRadio;
