import React from 'react';

import clsx from 'clsx';
import { nanoid } from 'nanoid';

export type KintonePluginSelectOptionData = {
  value: string;
  label: string;
  disabled?: boolean;
};

export type KintonePluginSelectProps = {
  className?: string;
  value: string;
  onChange: (value: string) => void;
  options: KintonePluginSelectOptionData[];
};

const KintonePluginSelect: React.FC<KintonePluginSelectProps> = (props) => {
  const { className, value, onChange, options } = props;
  if (!options || options.length === 0) {
    return null; // Return null if no options are provided
  }
  const key = nanoid();
  const handleOnChange = (e: React.ChangeEvent<HTMLSelectElement>) => {
    onChange(e.target.value);
  };
  return (
    <div className={clsx('kintoneplugin-select-outer', className)}>
      <div className="kintoneplugin-select">
        <select value={value} onChange={handleOnChange}>
          {options.map(({ value: itemValue, label, disabled }, idx) => (
            <option key={`${key}-k${idx}`} value={itemValue} disabled={disabled}>
              {label}
            </option>
          ))}
        </select>
      </div>
    </div>
  );
};
export default KintonePluginSelect;
